import Avatar from '@instructure/ui-elements/lib/components/Avatar'

import Spinner from '../../../../../common/components/shared/spinner/Spinner'

import ModerateTable from '../presenter'
import ModerateTableRow from '../../ModerateTableRow'

describe('ModerateTable presenter', () => {
  const props = {
    tableData: [
      { avatar: 'zomgModerateTablePresenter', id: '42', name: 'lolwut', quizSessionIds: ['1'] },
      { avatar: 'lulzModerateTablePresenter', id: '77', name: 'wutlol', quizSessionIds: ['2'] }
    ],
    onModerateButtonClick () {},
    onModerateLogClick () {}
  }

  const testbed = createTestbed(withContext(ModerateTable, {}), props)

  shouldRenderComponent(testbed, {}, ModerateTable)
  stubComponent(Avatar)

  it('renders a spinner while fetching', () => {
    testbed.render({ isFetching: true })
    const result = testbed.findChildByType(Spinner)
    expect(result).to.be.ok()
  })

  it('includes a helpful caption', () => {
    testbed.render()
    const output = testbed.getText()
    expect(output).to.include('Moderation Table')
  })

  it('includes a helpful message without table data', () => {
    testbed.render({ tableData: [] })
    const output = testbed.getText()
    expect(output).to.include('There is no moderation information')
  })

  it('allows for providing a custom emptyMessage via props', () => {
    testbed.render({ tableData: [], emptyMessage: 'quizzin aint easy' })
    const output = testbed.getText()
    expect(output).to.include('quizzin aint easy')
  })

  it('renders ModerateTableRow children as expected', () => {
    testbed.render()
    const result = testbed.findChildrenByType(ModerateTableRow)
    expect(result).to.have.length(2)
  })

  it('passes onModerateLogClick to table row children', () => {
    testbed.render()
    const { onModerateLogClick } = testbed.findChildrenByType(ModerateTableRow)[0].props
    expect(onModerateLogClick).to.eq(props.onModerateLogClick)
  })
})
